@@ -7,7 +7,7 @@
 
 package Couch::DB::Cluster;
 use vars '$VERSION';
-$VERSION = '0.004';
+$VERSION = '0.005';
 
 
 use Couch::DB::Util  qw/flat/;;
@@ -16,6 +16,7 @@ use Log::Report 'couch-db';
 
 use Scalar::Util  qw(weaken);
 use URI::Escape   qw(uri_escape);
+use Storable      qw(dclone);
 
 
 sub new(@) { my ($class, %args) = @_; (bless {}, $class)->init(\%args) }
@@ -39,9 +40,6 @@ sub couch() { $_[0]->{CDC_couch} }
 sub clusterState(%)
 {	my ($self, %args) = @_;
 
-	$args{client} || @{$args{client} || []}==1
-		or error __x"Explicitly name one client for clusterState().";
-
 	my %query;
 	my @need = flat delete $args{ensure_dbs_exists};
 	$query{ensure_dbs_exists} = $self->couch->jsonText(\@need, compact => 1)
@@ -55,28 +53,24 @@ sub clusterState(%)
 }
 
 
-sub clusterSetup(%)
-{	my ($self, %args) = @_;
-
-	$args{client} || @{$args{client} || []}==1
-		or error __x"Explicitly name one client for clusterSetup().";
+sub clusterSetup($%)
+{	my ($self, $config, %args) = @_;
 
+	$self->couch->toJSON($config, int => qw/port node_count/);
+	
 	$self->couch->call(POST => '/_cluster_setup',
 		introduced => '2.0.0',
-		send       => \%args,
+		send       => $config,
 		$self->couch->_resultsConfig(\%args),
 	);
 }
 
 #-------------
 
-#XXX The example in CouchDB API doc 3.3.3 says it returns 'reason' with /state,
-#XXX but the spec says 'state_reason'.
-
 sub reshardStatus(%)
 {	my ($self, %args) = @_;
 	my $path = '/_reshard';
-	$path   .= '/state' if delete $args{counts};
+	$path   .= '/state' unless delete $args{counts};
 
 	$self->couch->call(GET => $path,
 		introduced => '2.4.0',
@@ -85,9 +79,6 @@ sub reshardStatus(%)
 }
 
 
-#XXX The example in CouchDB API doc 3.3.3 says it returns 'reason' with /state,
-#XXX but the spec says 'state_reason'.
-
 sub resharding(%)
 {	my ($self, %args) = @_;
 
@@ -250,6 +241,7 @@ sub syncShards($%)
 {	my ($self, $db, %args) = @_;
 
 	$self->couch->call(POST => $db->_pathToDB('_sync_shards'),
+		send => {},
 		introduced => '2.3.1',
 		$self->couch->_resultsConfig(\%args),
 	);
